/*
 * L13_Water_Alert.ino
 * Sound the alarm when water is detected
 * 
 * FRSEF Crash Course V1 Lesson 13
 * Written by Chris Bergsneider 
 * cbergsneider@flintsciencefair.org
 * December 13, 2020
 */

// Display Library
#include <U8x8lib.h>


// Display Constructor
U8X8_SSD1306_128X64_ALT0_HW_I2C Display(/* reset=*/ U8X8_PIN_NONE); 

const byte pinWaterSensor = 2;
const byte pinLED = 4;
const byte pinBuzzer = 5;
const unsigned int frequency = 500;

const unsigned int interval = 1000; // interval between readings in ms

void setup()
{
  Serial.begin (9600);
  
  pinMode(pinWaterSensor, INPUT);
  pinMode(pinLED, OUTPUT);
  pinMode(pinBuzzer, OUTPUT);

  digitalWrite(pinLED, LOW);

  // Start the Display
  Display.begin();
  Display.setFlipMode(1);
  Display.setFont(u8x8_font_chroma48medium8_r);  
}

void loop()
{
  static unsigned long nextTime = 0; // at what time should we re-run the code
  unsigned long ms = millis(); // get the current time
  
  if (ms >= nextTime)
  {
    nextTime = ms + interval; 
    
    bool waterDetected = !digitalRead(pinWaterSensor); // read the water sensor.  if water is detected, sensor goes low, so negate the value
    digitalWrite(pinLED, waterDetected);
    
    if(waterDetected)
    {
      Serial.println(F("Water Detected!"));
      tone(pinBuzzer, frequency);
      Display.setCursor(0, 0);
      Display.print(F("Water Detected!"));
      
    }
    else
    {
      noTone(pinBuzzer);
      Display.clear();
    }
  }                                                                               
}
