/*
 * L14_Calibration.ino
 * Display the pot rotation in degrees.
 * Student activity to modify the calibration values
 * 
 * FRSEF Crash Course V1 Lesson 14
 * Written by Chris Bergsneider 
 * cbergsneider@flintsciencefair.org
 * December 16, 2020
 */

// Display Library
#include <U8x8lib.h>

// Display Constructor
U8X8_SSD1306_128X64_ALT0_HW_I2C Display(/* reset=*/ U8X8_PIN_NONE); 

const byte pinPot = A0;
const int deg90Count = 200;
const int deg270Count = 800;

const unsigned int interval = 100; // interval between readings in ms

void setup()
{
  Serial.begin (9600);

  // Start the Display
  Display.begin();
  Display.setFlipMode(1);
  Display.setFont(u8x8_font_chroma48medium8_r);
  Display.clear();
  Display.setCursor(0, 0);
  Display.print(F("Degrees  Raw"));
  Serial.println(F("Degrees\tRaw"));
}

void loop()
{
  static unsigned long nextTime = 0; // at what time should we re-run the code
  unsigned long ms = millis(); // get the current time
  
  if (ms >= nextTime)
  {
    nextTime = ms + interval; 

    int potValueRaw = analogRead(pinPot);
    int potValueDeg = map(potValueRaw, deg90Count, deg270Count, 90, 270);
    Display.setCursor(0, 1);
    Display.print(potValueDeg);
    Display.print(F("  "));
    Serial.print(potValueDeg);
    Serial.print('\t');
    Display.setCursor(9, 1);
    Display.print(potValueRaw);
    Display.print(F("  "));
    Serial.println(potValueRaw);
  }
}
